@@ -19,7 +19,7 @@ i586-pc-msdosdjgpp-gcc -v
 
 
 target=i586-pc-msdosdjgpp
-v1=$(echo 6.5.0 | sed -e 's:\.:2g')
+v1=$(echo 7.5.0 | sed -e 's:\.::2g')
 
 ../gnu/gcc-$v1/configure \
     --prefix=/dev/env/DJDIR \
