@@ -1,7 +1,7 @@
 #! /bin/sh
 
 top=`pwd`
-gcc_version=6.5.0
+gcc_version=7.5.0
 contact="Andris Pavenis <andris.pavenis@iki.fi>";
 
 # Configuration params
@@ -131,7 +131,9 @@ rm -rf $gcc_dir/liboffloadmic
 rm -rf $gcc_dir/libvtv
 
 if $remove_tests ; then
-    rm -rf $gcc_dir/gcc/testsuite
+    for name in $(cd $gcc_dir/gcc/testsuite && ls -1b | grep -v selftest); do
+        rm -rf $gcc_dir/gcc/testsuite/$name
+    done
 fi
 
 #
@@ -170,7 +172,7 @@ for copy_instr in $file_copy_list_1 $file_copy_list_2 ; do
     fi
     if ! [ -f $gcc_dir/$orig_fn ] ; then
         echo "ERROR: File $orig_fn is not found"
-        patching_ok=false
+         patching_ok=false
     fi
     cp -Pv $gcc_dir/$orig_fn $gcc_dir/$new_fn
 done
